@@ -1,4 +1,4 @@
-__version__ = "0.5.7"
+__version__ = "0.5.8"
 
 from .io import yaml_load, yaml_dump, save, load, json_load, json_dump
 from .path import *
@@ -8,9 +8,10 @@ from .async_api import ConcurrentRequester
 from .nlp.parser import parse_to_obj, parse_to_code
 from .ai_platform.metrics import MetricsCalculator, save_pred_metrics
 from .vllm.client.image_processor_helper import ImageProcessor
-from .vllm.client.messages_processor import batch_process_messages, messages_preprocess, ImageCacheConfig
+from .vllm.client.image_processor import ImageCacheConfig
+from .vllm.client.messages_processor import batch_process_messages, messages_preprocess
 from .llm.openaiclient import OpenAIClient
-from .mllm import MllmClient, MllmTableProcessor, MllmFolderProcessor
+from .mllm import MllmClient
 
 # from .decorators import benchmark
 # from .string.color_string import rgb_string
